==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MarketFacilitationIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MarketFacilitationIndexIndicator, _super);
    function MarketFacilitationIndexIndicator() {
        return _super.call(this) || this;
    }
    MarketFacilitationIndexIndicator.prototype.bi = function () {
        return new MarketFacilitationIndexIndicator();
    };
    MarketFacilitationIndexIndicator.prototype.get_aat = function () {
        return 1;
    };
    MarketFacilitationIndexIndicator.prototype.get_ab8 = function () {
        return new MarketFacilitationIndexIndicatorStrategy();
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "ab8", {
        get: function () {
            return this.get_ab8();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.prototype.get_abz = function () {
        return MarketFacilitationIndexIndicator.$;
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "abz", {
        get: function () {
            return this.get_abz();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.$t = markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MarketFacilitationIndexIndicator };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MarketFacilitationIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MarketFacilitationIndexIndicator, _super);
    function MarketFacilitationIndexIndicator() {
        return _super.call(this) || this;
    }
    MarketFacilitationIndexIndicator.prototype.bj = function () {
        return new MarketFacilitationIndexIndicator();
    };
    MarketFacilitationIndexIndicator.prototype.get_aa2 = function () {
        return 1;
    };
    MarketFacilitationIndexIndicator.prototype.get_ach = function () {
        return new MarketFacilitationIndexIndicatorStrategy();
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "ach", {
        get: function () {
            return this.get_ach();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.prototype.get_ab8 = function () {
        return MarketFacilitationIndexIndicator.$;
    };
    Object.defineProperty(MarketFacilitationIndexIndicator.prototype, "ab8", {
        get: function () {
            return this.get_ab8();
        },
        enumerable: false,
        configurable: true
    });
    MarketFacilitationIndexIndicator.$t = markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MarketFacilitationIndexIndicator };
